@@ -296,7 +296,10 @@ options_validity_check() {
 	local option_package
 	option_package=$(option_value 'package')
 	case "$option_package" in
-		('arch'|'deb'|'gentoo'|'egentoo') ;;
+		('arch'|'deb'|'gentoo') ;;
+		('egentoo')
+			warning_option_value_deprecated 'package' 'egentoo'
+		;;
 		(*)
 			error_option_invalid 'package' "$option_package"
 			return 1
