@@ -24,6 +24,15 @@ requirements_list() {
 	requirements_list="$requirements_list
 	$(requirements_list_archive)"
 
+	# If a WINE init .reg script is to be generated,
+	# ensure that iconv is available
+	local wine_registry_script_content
+	wine_registry_script_content=$(wine_registry_script_content)
+	if [ -n "$wine_registry_script_content" ]; then
+		requirements_list="$requirements_list
+		iconv"
+	fi
+
 	printf '%s' "$requirements_list" | list_clean
 }
 
@@ -32,13 +41,7 @@ requirements_list() {
 # RETURN: a list for required commands,
 #         separated by line breaks
 requirements_list_explicit() {
-	if [ -n "${REQUIREMENTS_LIST:-}" ]; then
-		printf '%s\n' "$REQUIREMENTS_LIST"
-		return 0
-	fi
-
-	# List requirements set by the legacy $SCRIPT_DEPS variable
-	requirements_list_explicit_legacy
+	context_value 'REQUIREMENTS_LIST'
 }
 
 # List requirements for the current archive integrity setting
@@ -94,19 +97,28 @@ requirements_list_icons() {
 		return 0
 	fi
 
-	# Fetch the list of icons
-	# This step is allowed to fail, as the current game script might not support any icon
+	# Fetch the list of icons.
 	local icons_list
-	icons_list=$(icons_list_all) 2>/dev/null || true
+	icons_list=$(icons_list_all)
 	# Return early if there is no icon for the current game script
 	if [ -z "$icons_list" ]; then
 		return 0
 	fi
 
 	# Print requirements for each icon.
-	local icon icon_path
+	local icon icon_path game_engine
+	game_engine=$(game_engine)
 	for icon in $icons_list; do
-		icon_path=$(icon_path "$icon" 2>/dev/null || true)
+		## This is allowed to fail for Unity3D games,
+		## because we might not know the icon path before the archive extraction.
+		case "$game_engine" in
+			('unity3d')
+				icon_path=$(icon_path "$icon" 2>/dev/null) || continue
+			;;
+			(*)
+				icon_path=$(icon_path "$icon")
+			;;
+		esac
 		case "$icon_path" in
 			(*'.png')
 				printf '%s\n' 'identify'
