@@ -60,19 +60,19 @@ application_type() {
 	printf '%s' "$application_type"
 }
 
-# Try to find the application type from the MIME type of its binary file
+# Try to find the application type from the MIME type of its binary file.
+# An empty string is returned if no type could be guessed.
 # USAGE: application_type_guess_from_file $application
-# RETURN: the guessed application type,
-#         or an empty string if none could be guessed
 application_type_guess_from_file() {
-	local application
+	local application application_type
 	application="$1"
+	application_type=''
 
 	# Get the path to the application binary.
-	local application_exe application_exe_path
+	local application_exe
 	application_exe=$(application_exe "$application")
-
-	# If no binary is found for the current package, try to find one for any of the packages.
+	## If no binary is found for the current package,
+	## try to find one for any of the packages.
 	if [ -z "$application_exe" ]; then
 		local package packages_list
 		packages_list=$(packages_list)
@@ -86,21 +86,21 @@ application_type_guess_from_file() {
 			fi
 		done
 	fi
-
-	# Return early if no binary seems to be set for the current application.
+	## Return early if no binary is set for the current application.
 	if [ -z "$application_exe" ]; then
 		return 0
 	fi
 
 	# Compute the full path to the application binary.
+	local application_exe_path
 	application_exe_path=$(application_exe_path "$application_exe")
-
-	# Return early if no binary file can be found for the given application.
+	## Return early if no binary file can be found for the given application.
 	if [ -z "$application_exe_path" ]; then
 		return 0
 	fi
 
-	local file_type application_type
+	# Guess the application type from its binary file MIME type.
+	local file_type file_type_extended
 	file_type=$(file_type "$application_exe_path")
 	case "$file_type" in
 		( \
@@ -114,7 +114,6 @@ application_type_guess_from_file() {
 			'application/x-dosexec' | \
 			'application/vnd.microsoft.portable-executable' \
 		)
-			local file_type_extended
 			file_type_extended=$(env --ignore-environment file --brief --dereference "$application_exe_path")
 			case "$file_type_extended" in
 				( \
@@ -135,10 +134,9 @@ application_type_guess_from_file() {
 			esac
 		;;
 		('application/octet-stream')
-			local file_type_extended
 			file_type_extended=$(env --ignore-environment file --brief --dereference "$application_exe_path")
 			case "$file_type_extended" in
-				('MS-DOS executable')
+				('MS-DOS executable'*)
 					application_type='dosbox'
 				;;
 			esac
