@@ -9,14 +9,12 @@ archive_extraction_using_lha() {
 	local archive_path
 	archive_path=$(archive_path "$archive")
 
-	local archive_extraction_return_code
 	# Due to its unusual command syntax, lha extractor has no support for ARCHIVE_xxx_EXTRACTOR_OPTIONS
-	printf 'lha -ew="%s" "%s"\n' "$destination_directory" "$archive_path" >> "$log_file"
-	{
-		lha -ew="$destination_directory" "$archive_path" >> "$log_file" 2>&1
-		archive_extraction_return_code=$?
-	} || true
-	if [ $archive_extraction_return_code -ne 0 ]; then
+	if ! {
+		printf 'lha -ew="%s" "%s"\n' "$destination_directory" "$archive_path"
+		lha -ew="$destination_directory" "$archive_path" 2>&1
+	} >> "$log_file"
+	then
 		error_archive_extraction_failure "$archive"
 		return 1
 	fi
