@@ -79,7 +79,10 @@ launcher_generation_checks() {
 			## ScummVM games do not rely on a provided binary,
 			## but they expect a ScummVM game ID to be set.
 			local application_scummid
-			application_scummid=$(application_scummvm_scummid "$application")
+			application_scummid=$(
+				set_current_package "$package"
+				application_scummvm_scummid "$application"
+			)
 			if [ -z "$application_scummid" ]; then
 				error_application_scummid_invalid "$application" "$application_scummid"
 				return 1
@@ -188,7 +191,15 @@ launcher_write_script() {
 				native_launcher "$application"
 			)
 			printf '%s' "$launcher_content" | snippet_clean > "$launcher_path"
-			## Add execution permissions to the game binary file.
+
+			# Build the .so preload shim, if one is set
+			local ld_preload_source
+			ld_preload_source=$(ld_preload_source)
+			if [ -n "$ld_preload_source" ]; then
+				ld_preload_build "$package"
+			fi
+
+			# Add execution permissions to the game binary file
 			local application_exe application_exe_path
 			application_exe=$(
 				set_current_package "$package"
@@ -199,7 +210,8 @@ launcher_write_script() {
 				application_exe_path "$application_exe"
 			)
 			chmod +x "$application_exe_path"
-			## Add dependencies on some system-provided libraries based on the game engine
+
+			# Add dependencies on some system-provided libraries based on the game engine
 			local game_engine
 			game_engine=$(game_engine)
 			case "$game_engine" in
@@ -225,6 +237,9 @@ launcher_write_script() {
 			dependencies_add_command "$package" 'scummvm'
 		;;
 		('wine')
+			# Generate the init .reg script, if set from the game script
+			wine_registry_script_write "$package"
+
 			launcher_content=$(
 				set_current_package "$package"
 				wine_launcher "$application"
