@@ -13,11 +13,8 @@ native_launcher() {
 			# Set the paths that should be available to the generated launcher
 			launcher_init_paths "$application"
 
-			native_launcher_environment "$application"
-
 			# Generate the game prefix
-			prefix_generate_links_farm
-			launcher_prefix_symlinks_build
+			prefix_symlinks_generate
 
 			# Set up the paths diversion to persistent storage
 			local fake_home_persistent_directories
@@ -44,7 +41,6 @@ native_launcher() {
 			# Set the paths that should be available to the generated launcher
 			launcher_init_paths "$application"
 
-			native_launcher_environment "$application"
 			native_launcher_run "$application"
 			launcher_exit
 		;;
@@ -55,23 +51,6 @@ native_launcher() {
 	esac
 }
 
-# Linux native launcher - Set the environment
-# USAGE: native_launcher_environment $application
-native_launcher_environment() {
-	local application
-	application="$1"
-
-	local application_exe
-	application_exe=$(application_exe_escaped "$application")
-
-	cat <<- EOF
-	# Set the environment
-
-	APP_EXE='$application_exe'
-
-	EOF
-}
-
 # Linux native launcher - Run the game binary
 # USAGE: native_launcher_run $application
 native_launcher_run() {
@@ -115,20 +94,6 @@ native_launcher_run() {
 
 			# Force the use of the system SDL library
 			launcher_tweak_sdl_override
-
-			# Unity3D 4.x and 5.x - Disable the MAP_32BIT flag to prevent a crash one some Linux versions when running a 64-bit build
-			local unity3d_version
-			unity3d_version=$(unity3d_version)
-			case "$unity3d_version" in
-				('4.'*|'5.'*)
-					local package package_architecture
-					package=$(current_package)
-					package_architecture=$(package_architecture "$package")
-					if [ "$package_architecture" = '64' ]; then
-						unity3d_disable_map32bit
-					fi
-				;;
-			esac
 		;;
 		('visionaire')
 			# Force the use of the system SDL library
@@ -158,8 +123,17 @@ native_launcher_run() {
 	cat <<- 'EOF'
 	## Set the preload paths for native libraries
 	export LD_LIBRARY_PATH="${PATH_LIBRARIES_USER}:${PATH_LIBRARIES_SYSTEM}:${LD_LIBRARY_PATH:-}"
-
 	EOF
+	local ld_preload_source
+	ld_preload_source=$(ld_preload_source)
+	if [ -n "$ld_preload_source" ]; then
+		local path_libraries
+		path_libraries=$(path_libraries)
+		cat <<- EOF
+		export LD_PRELOAD="\${LD_PRELOAD:-}:${path_libraries}/preload-hack.so"
+		EOF
+	fi
+	printf '\n'
 
 	application_prerun "$application"
 
@@ -196,10 +170,18 @@ native_launcher_run() {
 # Linux native launcher - Copy the game binary into the game prefix
 # USAGE: native_launcher_binary_copy
 native_launcher_binary_copy() {
+	local application_exe exe_destination
+	application_exe=$(application_exe_escaped "$application")
+	exe_destination="\${PATH_PREFIX}/${application_exe}"
+
 	cat <<- 'EOF'
 	# Copy the game binary into the user prefix
 
-	exe_destination="${PATH_PREFIX}/${APP_EXE}"
+	EOF
+	cat <<- EOF
+	exe_destination="${exe_destination}"
+	EOF
+	cat <<- 'EOF'
 	if [ -h "$exe_destination" ]; then
 	    exe_source=$(realpath "$exe_destination")
 	    cp --remove-destination "$exe_source" "$exe_destination"
@@ -216,10 +198,11 @@ native_exec_line() {
 	local application
 	application="$1"
 
-	local application_options
+	local application_exe application_options
+	application_exe=$(application_exe_escaped "$application")
 	application_options=$(application_options "$application")
 	cat <<- EOF
-	"./\$APP_EXE" $application_options "\$@"
+	"./${application_exe}" $application_options "\$@"
 	EOF
 }
 
