@@ -26,6 +26,7 @@ wine_dlloverrides_default() {
 # USAGE: wine_launcher_wineprefix_environment
 wine_launcher_wineprefix_environment() {
 	# Set compatibility links to legacy paths
+	## TODO: env --chdir could be used instead of cd in a subshell.
 	cat <<- 'EOF'
 	# Set compatibility link to a legacy user path
 	wineprefix_legacy_link() {
@@ -94,8 +95,8 @@ wine_wineprefix_init_actions() {
 	game_id=$(game_id)
 	cat <<- EOF
 	    ## Link the game prefix into the WINE prefix
-	    ln --symbolic \
-	        "\$PATH_PREFIX" \
+	    ln --symbolic \\
+	        "\$PATH_PREFIX" \\
 	        "\${WINEPREFIX}/drive_c/${game_id}"
 
 	EOF
@@ -114,6 +115,16 @@ wine_wineprefix_init_actions() {
 	    wineprefix_legacy_link 'Documents' 'My Documents'
 
 	EOF
+	## Include custom actions set from the game script
+	wineprefix_init_custom
+}
+
+# WINE - Set custom actions to run on prefix initialization
+# USAGE: wineprefix_init_custom
+wineprefix_init_custom() {
+	# This function prints nothing by default,
+	# it should be overridden from game scripts to have any effect
+	return 0
 }
 
 # WINE launcher - Generate the WINE prefix
