@@ -36,12 +36,25 @@ dependency_package_providing_library_arch() {
 	local library package_name
 	library="$1"
 	case "$library" in
+		('alleg-alsadigi.so')
+			package_name='allegro4'
+		;;
+		('alleg-alsamidi.so')
+			package_name='allegro4'
+		;;
 		('ld-linux.so.2')
 			package_name='glibc'
 		;;
 		('ld-linux-x86-64.so.2')
 			package_name='glibc'
 		;;
+		('libaldmb.so.1')
+			# This library is not provided for Arch Linux
+			unset package_name
+		;;
+		('liballeg.so.4.4')
+			package_name='allegro4'
+		;;
 		('liballegro.so.5.2')
 			package_name='allegro'
 		;;
@@ -84,10 +97,6 @@ dependency_package_providing_library_arch() {
 		('libaudio.so.2')
 			package_name='nas'
 		;;
-		('libboost_locale.so.1.74.0')
-			# This library is not provided for Arch Linux
-			unset package_name
-		;;
 		('libbz2.so.1.0'|'libbz2.so.1')
 			package_name='bzip2'
 		;;
@@ -144,6 +153,10 @@ dependency_package_providing_library_arch() {
 		('libdrm.so.2')
 			package_name='libdrm'
 		;;
+		('libdumb.so.1')
+			# This library is not provided for Arch Linux
+			unset package_name
+		;;
 		('libEGL.so.1')
 			package_name='libglvnd'
 		;;
@@ -278,9 +291,6 @@ dependency_package_providing_library_arch() {
 		('libmbedtls.so.12')
 			package_name='mbedtls'
 		;;
-		('libminiupnpc.so.17')
-			package_name='miniupnpc'
-		;;
 		('libminizip.so.1')
 			package_name='minizip'
 		;;
@@ -394,6 +404,9 @@ dependency_package_providing_library_arch() {
 		('libSDL2_image-2.0.so.0')
 			package_name='sdl2_image'
 		;;
+		('libSDL2_net-2.0.so.0')
+			package_name='sdl2_net'
+		;;
 		('libSDL2_mixer-2.0.so.0')
 			package_name='sdl2_mixer'
 		;;
@@ -583,12 +596,28 @@ dependency_package_providing_library_arch32() {
 	local library package_name
 	library="$1"
 	case "$library" in
+		('alleg-alsadigi.so')
+			# This library is not provided in a 32-bit build for Arch Linux
+			unset package_name
+		;;
+		('alleg-alsamidi.so')
+			# This library is not provided in a 32-bit build for Arch Linux
+			unset package_name
+		;;
 		('ld-linux.so.2')
 			package_name='lib32-glibc'
 		;;
 		('ld-linux-x86-64.so.2')
 			package_name='lib32-glibc'
 		;;
+		('libaldmb.so.1')
+			# This library is not provided for Arch Linux
+			unset package_name
+		;;
+		('liballeg.so.4.4')
+			# This library is not provided in a 32-bit build for Arch Linux
+			unset package_name
+		;;
 		('liballegro.so.5.2')
 			package_name='lib32-allegro'
 		;;
@@ -632,10 +661,6 @@ dependency_package_providing_library_arch32() {
 			# This library is not provided in a 32-bit build for Arch Linux
 			unset package_name
 		;;
-		('libboost_locale.so.1.74.0')
-			# This library is not provided for Arch Linux
-			unset package_name
-		;;
 		('libbz2.so.1.0'|'libbz2.so.1')
 			package_name='lib32-bzip2'
 		;;
@@ -694,6 +719,10 @@ dependency_package_providing_library_arch32() {
 		('libdrm.so.2')
 			package_name='lib32-libdrm'
 		;;
+		('libdumb.so.1')
+			# This library is not provided for Arch Linux
+			unset package_name
+		;;
 		('libEGL.so.1')
 			package_name='lib32-libglvnd'
 		;;
@@ -831,10 +860,6 @@ dependency_package_providing_library_arch32() {
 			# This library is not provided in a 32-bit build for Arch Linux
 			unset package_name
 		;;
-		('libminiupnpc.so.17')
-			# This library is not provided in a 32-bit build for Arch Linux
-			unset package_name
-		;;
 		('libminizip.so.1')
 			package_name='lib32-minizip'
 		;;
@@ -950,6 +975,10 @@ dependency_package_providing_library_arch32() {
 		('libSDL2_image-2.0.so.0')
 			package_name='lib32-sdl2_image'
 		;;
+		('libSDL2_net-2.0.so.0')
+			# This library is not provided in a 32-bit build for Arch Linux.
+			unset package_name
+		;;
 		('libSDL2_mixer-2.0.so.0')
 			package_name='lib32-sdl2_mixer'
 		;;
