@@ -171,15 +171,12 @@ debian_package_build_single() {
 	esac
 
 	# Run the actual package generation, using dpkg-deb
-	local TMPDIR package_generation_return_code
+	local TMPDIR
 	information_package_building "$package_name"
 	## We need to explicitly export TMPDIR, or dpkg-deb will not pick it up.
 	export TMPDIR="$PLAYIT_WORKDIR"
-	{
-		dpkg-deb ${dpkg_options:-} --build "$package_path" "$generated_package_path" 1>/dev/null
-		package_generation_return_code=$?
-	} || true
-	if [ $package_generation_return_code -ne 0 ]; then
+	if ! dpkg-deb ${dpkg_options:-} --build "$package_path" "$generated_package_path" 1>/dev/null
+	then
 		error_package_generation_failed "$package_name"
 		return 1
 	fi
