@@ -20,12 +20,24 @@ dependency_package_providing_library_deb() {
 	local library package_name
 	library="$1"
 	case "$library" in
+		('alleg-alsadigi.so')
+			package_name='liballegro4.4'
+		;;
+		('alleg-alsamidi.so')
+			package_name='liballegro4.4'
+		;;
 		('ld-linux.so.2')
 			package_name='libc6'
 		;;
 		('ld-linux-x86-64.so.2')
 			package_name='libc6'
 		;;
+		('libaldmb.so.1')
+			package_name='libaldmb1'
+		;;
+		('liballeg.so.4.4')
+			package_name='liballegro4.4'
+		;;
 		('liballegro.so.5.2')
 			package_name='liballegro5.2'
 		;;
@@ -68,9 +80,6 @@ dependency_package_providing_library_deb() {
 		('libaudio.so.2')
 			package_name='libaudio2'
 		;;
-		('libboost_locale.so.1.74.0')
-			package_name='libboost-locale1.74.0'
-		;;
 		('libbz2.so.1.0'|'libbz2.so.1')
 			package_name='libbz2-1.0'
 		;;
@@ -127,6 +136,9 @@ dependency_package_providing_library_deb() {
 		('libdrm.so.2')
 			package_name='libdrm2'
 		;;
+		('libdumb.so.1')
+			package_name='libdumb1'
+		;;
 		('libEGL.so.1')
 			package_name='libegl1'
 		;;
@@ -268,9 +280,6 @@ dependency_package_providing_library_deb() {
 		('libmbedtls.so.12')
 			package_name='libmbedtls12'
 		;;
-		('libminiupnpc.so.17')
-			package_name='libminiupnpc17'
-		;;
 		('libminizip.so.1')
 			package_name='libminizip1'
 		;;
@@ -384,6 +393,9 @@ dependency_package_providing_library_deb() {
 		('libSDL2_image-2.0.so.0')
 			package_name='libsdl2-image-2.0-0'
 		;;
+		('libSDL2_net-2.0.so.0')
+			package_name='libsdl2-net-2.0-0'
+		;;
 		('libSDL2_mixer-2.0.so.0')
 			package_name='libsdl2-mixer-2.0-0'
 		;;
