@@ -45,12 +45,25 @@ dependency_package_providing_library_gentoo() {
 	library="$1"
 	package="$2"
 	case "$library" in
+		('alleg-alsadigi.so')
+			package_name='media-libs/allegro'
+		;;
+		('alleg-alsamidi.so')
+			package_name='media-libs/allegro'
+		;;
 		('ld-linux.so.2')
 			package_name='sys-libs/glibc'
 		;;
 		('ld-linux-x86-64.so.2')
 			package_name='sys-libs/glibc'
 		;;
+		('libaldmb.so.1')
+			# This library is not provided for Gentoo
+			unset package_name
+		;;
+		('liballeg.so.4.4')
+			package_name='media-libs/allegro'
+		;;
 		('liballegro.so.5.2')
 			package_name='media-libs/allegro'
 		;;
@@ -93,10 +106,6 @@ dependency_package_providing_library_gentoo() {
 		('libaudio.so.2')
 			package_name='media-libs/nas'
 		;;
-		('libboost_locale.so.1.74.0')
-			# This library is not provided for Gentoo
-			unset package_name
-		;;
 		('libbz2.so.1.0'|'libbz2.so.1')
 			package_name='app-arch/bzip2'
 		;;
@@ -157,6 +166,10 @@ dependency_package_providing_library_gentoo() {
 		('libdrm.so.2')
 			package_name='x11-libs/libdrm'
 		;;
+		('libdumb.so.1')
+			# This library is not provided for Gentoo
+			unset package_name
+		;;
 		('libEGL.so.1')
 			package_name='media-libs/libglvnd'
 		;;
@@ -295,9 +308,6 @@ dependency_package_providing_library_gentoo() {
 		('libmbedtls.so.12')
 			package_name='net-libs/mbedtls:0/12'
 		;;
-		('libminiupnpc.so.17')
-			package_name='net-libs/miniupnpc'
-		;;
 		('libminizip.so.1')
 			package_name='sys-libs/zlib'
 		;;
@@ -412,6 +422,9 @@ dependency_package_providing_library_gentoo() {
 			# Maybe we should add gif and tiff to that list?
 			package_name='media-libs/sdl2-image[jpeg,png]'
 		;;
+		('libSDL2_net-2.0.so.0')
+			package_name='media-libs/sdl2-net'
+		;;
 		('libSDL2_mixer-2.0.so.0')
 			# Most games will require at least one of flac, mp3, vorbis or wav USE flags,
 			# it should better to require them all instead of not requiring any
@@ -606,12 +619,25 @@ dependency_package_providing_library_gentoo32() {
 	library="$1"
 	package="$2"
 	case "$library" in
+		('alleg-alsadigi.so')
+			package_name='media-libs/allegro[abi_x86_32]'
+		;;
+		('alleg-alsamidi.so')
+			package_name='media-libs/allegro[abi_x86_32]'
+		;;
 		('ld-linux.so.2')
 			package_name='sys-libs/glibc amd64? ( sys-libs/glibc[multilib] )'
 		;;
 		('ld-linux-x86-64.so.2')
 			package_name='sys-libs/glibc amd64? ( sys-libs/glibc[multilib] )'
 		;;
+		('libaldmb.so.1')
+			# This library is not provided for Gentoo
+			unset package_name
+		;;
+		('liballeg.so.4.4')
+			package_name='media-libs/allegro[abi_x86_32]'
+		;;
 		('liballegro.so.5.2')
 			package_name='media-libs/allegro[abi_x86_32]'
 		;;
@@ -654,10 +680,6 @@ dependency_package_providing_library_gentoo32() {
 		('libaudio.so.2')
 			package_name='media-libs/nas[abi_x86_32]'
 		;;
-		('libboost_locale.so.1.74.0')
-			# This library is not provided for Gentoo
-			unset package_name
-		;;
 		('libbz2.so.1.0'|'libbz2.so.1')
 			package_name='app-arch/bzip2[abi_x86_32]'
 		;;
@@ -718,6 +740,10 @@ dependency_package_providing_library_gentoo32() {
 		('libdrm.so.2')
 			package_name='x11-libs/libdrm[abi_x86_32]'
 		;;
+		('libdumb.so.1')
+			# This library is not provided for Gentoo
+			unset package_name
+		;;
 		('libEGL.so.1')
 			package_name='media-libs/libglvnd[abi_x86_32]'
 		;;
@@ -856,9 +882,6 @@ dependency_package_providing_library_gentoo32() {
 		('libmbedtls.so.12')
 			package_name='net-libs/mbedtls:0/12[abi_x86_32]'
 		;;
-		('libminiupnpc.so.17')
-			package_name='net-libs/miniupnpc[abi_x86_32]'
-		;;
 		('libminizip.so.1')
 			package_name='sys-libs/zlib[abi_x86_32]'
 		;;
@@ -973,6 +996,9 @@ dependency_package_providing_library_gentoo32() {
 			# Maybe we should add gif and tiff to that list?
 			package_name='media-libs/sdl2-image[jpeg,png,abi_x86_32]'
 		;;
+		('libSDL2_net-2.0.so.0')
+			package_name='media-libs/sdl2-net[abi_x86_32]'
+		;;
 		('libSDL2_mixer-2.0.so.0')
 			# Most games will require at least one of flac, mp3, vorbis or wav USE flags,
 			# it should better to require them all instead of not requiring any
