@@ -202,27 +202,6 @@ test_application_prerun() {
 	APP_MAIN_PRERUN='some commands'
 	application_prerun=$(application_prerun 'APP_MAIN')
 	assertEquals 'some commands' "$application_prerun"
-
-	# Check that LD_PRELOAD hacks are automatically added
-	hacks_included_in_package() {
-		printf '%s\n' 'HACK_SDL1COMPAT' 'HACK_NOATIME'
-	}
-	path_libraries() {
-		printf '/usr/lib/games/some-game'
-	}
-	HACK_SDL1COMPAT_NAME='smacshim'
-	HACK_SDL1COMPAT_DESCRIPTION='LD_PRELOAD shim allowing the old engine to run on top of latest SDL1 library
-cf. https://github.com/ZeroPointEnergy/smacshim'
-	HACK_NOATIME_NAME='vv_noatime'
-	HACK_NOATIME_DESCRIPTION='LD_PRELOAD shim working around the engine expectation that files are owned by the current user'
-	application_prerun=$(application_prerun 'APP_MAIN')
-	application_prerun_expected='some commands
-# LD_PRELOAD shim allowing the old engine to run on top of latest SDL1 library
-# cf. https://github.com/ZeroPointEnergy/smacshim
-export LD_PRELOAD="${LD_PRELOAD}:/usr/lib/games/some-game/preload-hacks/smacshim.so"
-# LD_PRELOAD shim working around the engine expectation that files are owned by the current user
-export LD_PRELOAD="${LD_PRELOAD}:/usr/lib/games/some-game/preload-hacks/vv_noatime.so"'
-	assertEquals "$application_prerun_expected" "$application_prerun"
 }
 
 test_application_postrun() {
